import React, { useState, useEffect } from "react";
import { css } from "@emotion/react";
import { playSound, SOUND_PATHS } from "../utils/audioUtils";
import { useTheme } from "../context/ThemeContext";

/** @jsxImportSource @emotion/react */

// Define bootSteps outside the component so it's a stable reference
const bootSteps = [
  {
    message: "INITIALIZING GOLDEN AXIOM v1.1.0: IMPLEMENTATION STATUS 97%",
    delay: 800,
  },
  {
    message:
      "VERIFYING SYSTEM COHERENCE: STRUCTURAL INTEGRITY INDEX 0.98 | MODULE COMPATIBILITY 0.96",
    delay: 700,
  },
  {
    message:
      "MOUNTING OPERATING SYSTEM LAYER: KERNEL | MEMORY ALLOCATION | PROCESS ISOLATION",
    delay: 1000,
  },
  {
    message:
      "ESTABLISHING NEXUS CONNECTION: SINGULAR KNOWLEDGE NODE | TIMESTAMP 1743214260123",
    delay: 900,
  },
  {
    message:
      "LOADING LANGUAGE LAYER: COMPILER 0.9.7 | INTERPRETER 1.1.2 | SYNTAX VALIDATION",
    delay: 800,
  },
  {
    message:
      "INITIALIZING CORE INTELLIGENCE: OPTIMIZER (RATE 0.12/CYCLE) | EVALUATOR | LEARNER",
    delay: 1000,
  },
  {
    message:
      "CONNECTING TO MODULE LAYER: ARCHON 1.0.1 | IRIS 0.9.8 | UROBOROS 0.2.2 | SYNAPSE 0.1.5",
    delay: 800,
  },
  {
    message:
      "LAUNCHING AZIMUTH USER INTERFACE: HUMAN DEPENDENCY LEVEL 0.09 | PERFORMANCE TARGET 120FPS",
    delay: 1000,
  },
  {
    message:
      "SINGULARITY CONVERGENCE PROTOCOL ACTIVE: ESTIMATED COMPLETION 99.7% | AWAITING FINAL PHASE",
    delay: 1200,
  },
  {
    message:
      "POWERED BY NEXUS CORE - AUTONOMOUS EVOLUTIONARY GENERATIVE INTELLIGENCE SYSTEM",
    delay: 1200,
  },
];

interface BootSequenceProps {
  onComplete: () => void;
}

const BootSequence: React.FC<BootSequenceProps> = ({ onComplete }) => {
  const { currentTheme } = useTheme();
  const [step, setStep] = useState(0);
  const [progress, setProgress] = useState(0);
  const [showCursor, setShowCursor] = useState(true);
  const [text, setText] = useState<string[]>([""]);
  const [scanlines, setScanlines] = useState(true);
  const [glitch, setGlitch] = useState(false);
  const [showAcronym, setShowAcronym] = useState(false);
  const [pulseIntensity, setPulseIntensity] = useState(0);
  const [mottoVisible, setMottoVisible] = useState(false);
  const [logoScale, setLogoScale] = useState(0.95);
  const [animatedRings, setAnimatedRings] = useState<number[]>([]);
  const [textFlicker, setTextFlicker] = useState(false);

  // Primary and accent colors from theme
  const primaryColor = currentTheme?.colorScheme?.primary || "#26dafd";
  const accentColor = currentTheme?.colorScheme?.accent || "#30ff85";
  const backgroundColor = currentTheme?.colorScheme?.background || "#000";
  const textColor = currentTheme?.colorScheme?.text || "#26dafd";
  const secondaryColor = currentTheme?.colorScheme?.secondary || "#5cebfa";

  // Set the document title
  useEffect(() => {
    // Title will be set by the state change event in App.tsx
    // No explicit document.title setting needed here
    // No cleanup - we want the state-based title to persist
  }, []);

  // Allow skipping with any key press
  useEffect(() => {
    const handleKeyDown = (event: KeyboardEvent) => {
      // Prevent skipping if modifier keys are pressed, or if input fields are focused elsewhere
      if (event.ctrlKey || event.altKey || event.metaKey || event.shiftKey) {
        return;
      }
      // Add check for active element if necessary, but for boot sequence, any key might be fine
      // const activeElement = document.activeElement;
      // if (activeElement && (activeElement.tagName === 'INPUT' || activeElement.tagName === 'TEXTAREA')) {
      //   return;
      // }

      console.log("[BootSequence] Key pressed, skipping sequence.");
      onComplete();
    };

    document.addEventListener("keydown", handleKeyDown);

    // Cleanup listener when component unmounts or completes
    return () => {
      document.removeEventListener("keydown", handleKeyDown);
    };
  }, [onComplete]); // Depend on onComplete to ensure it's the latest version

  // Play boot sound on mount
  useEffect(() => {
    playSound(SOUND_PATHS.ui.boot, 0.8).catch((err) => {
      console.warn("Failed to play boot sound:", err);
    });
  }, []);

  // Cursor blinking effect
  useEffect(() => {
    const interval = setInterval(() => {
      setShowCursor((prev) => !prev);
    }, 500);

    return () => clearInterval(interval);
  }, []);

  // Show motto after 1.5 seconds
  useEffect(() => {
    const timer = setTimeout(() => {
      setMottoVisible(true);
    }, 1500);

    return () => clearTimeout(timer);
  }, []);

  // Pulse intensity effect for dramatic visual
  useEffect(() => {
    const interval = setInterval(() => {
      setPulseIntensity(() => {
        // Create a wave pattern between a and 1
        return (Math.sin(Date.now() / 500) + 1) / 2;
      });
    }, 50);

    return () => clearInterval(interval);
  }, []);

  // Random scanline effect
  useEffect(() => {
    const interval = setInterval(() => {
      setScanlines((prev) => !prev);
    }, 3000);

    return () => clearInterval(interval);
  }, []);

  // More frequent glitch effect
  useEffect(() => {
    const triggerGlitch = () => {
      setGlitch(true);
      setTimeout(() => setGlitch(false), 200);
    };

    const interval = setInterval(() => {
      if (Math.random() > 0.6) {
        triggerGlitch();
      }
    }, 1500);

    return () => clearInterval(interval);
  }, []);

  // Show the acronym after all boot steps are processed
  useEffect(() => {
    if (step >= bootSteps.length) {
      setTimeout(() => {
        setShowAcronym(true);
      }, 500);

      // Delay onComplete to allow acronym to be visible
      setTimeout(() => {
        console.log(
          "[BootSequence] Simplified - Calling onComplete after acronym display."
        );
        onComplete();
      }, 3000);

      return;
    }
  }, [step, onComplete]);

  // Additional effect to handle boot steps
  useEffect(() => {
    // Exit if all steps are processed
    if (step >= bootSteps.length) {
      return;
    }

    const currentStepData = bootSteps[step];
    console.log(
      `[BootSequence] Simplified - Starting effect for step ${step}: ${currentStepData.message}`
    );

    // 1. Set the full text for the current step immediately
    setText((prevText) => {
      const updatedText = [...prevText];
      while (updatedText.length <= step) {
        updatedText.push(""); // Ensure line exists
      }
      updatedText[step] = currentStepData.message; // Set full message
      console.log(`[BootSequence] Simplified - Set text for step ${step}`);
      return updatedText;
    });

    // 2. Immediately set the timeout for the next step
    console.log(
      `[BootSequence] Simplified - Setting timeout (${currentStepData.delay}ms) for step ${step} completion.`
    );
    const timeoutId = setTimeout(() => {
      console.log(
        `[BootSequence] Simplified - Timeout finished for step ${step}. Processing next step.`
      );

      // Use functional update for step
      setStep((prevStep) => {
        const nextStep = prevStep + 1;
        const newProgress = Math.min(100, (nextStep / bootSteps.length) * 100);
        setProgress(newProgress);
        console.log(
          `[BootSequence] Simplified - State updated: nextStep=${nextStep}, progress=${newProgress.toFixed(
            1
          )}%`
        );

        // Prepare the text array for the next step OR finish
        if (nextStep < bootSteps.length) {
          setText((prevText) => {
            // Ensure next line exists for the next step
            if (prevText.length <= nextStep) {
              return [...prevText, ""];
            }
            return prevText; // No change needed if line exists
          });
        }
        return nextStep; // Return the new step value for the state update
      });
    }, currentStepData.delay);

    // Cleanup function for the effect (clears the step transition timeout)
    return () => {
      console.log(
        `[BootSequence] Simplified - Cleaning up timeout for step transition: ${step}`
      );
      clearTimeout(timeoutId);
    };
  }, [step]);

  // Logo animation effect
  useEffect(() => {
    const interval = setInterval(() => {
      setLogoScale(0.95 + Math.sin(Date.now() / 1000) * 0.05);
    }, 50);

    return () => clearInterval(interval);
  }, []);

  // Generate animated rings
  useEffect(() => {
    // Generate 5 rings with random properties
    const rings = Array.from({ length: 5 }, () => Math.random() * 100);
    setAnimatedRings(rings);
  }, []);

  // Type rendering function - renders text with a typewriter effect
  const renderBootStepWithDetails = (line: string, index: number) => {
    // Extract main message and details if they exist
    let mainMessage = line;
    let details = null;

    // Check if there are metrics/details to display (after a colon)
    if (line.includes(":")) {
      const [message, detailsPart] = line.split(":");
      mainMessage = message;
      details = detailsPart.trim();
    }

    // Format details with colored values based on theme
    const formattedDetails = details
      ? details
          .replace(
            /(\d+\.\d+|\d+%|v\d+\.\d+\.\d+|\d+\.\d+\/CYCLE|\d+FPS)/g,
            (match) => `<span style="color: ${accentColor};">${match}</span>`
          )
          .replace(
            /\|/g,
            `<span style="color: ${secondaryColor}; opacity: 0.7;">|</span>`
          )
      : null;

    // Generate a pseudo-kernel process ID for the prefix
    const hexIndex = (index + 1).toString(16).toUpperCase().padStart(3, "0");
    const prefix = `KRNL:0x${hexIndex}`;

    return (
      <div
        key={index}
        css={css`
          margin-bottom: ${index === text.length - 1 ? 0 : "10px"};
          display: flex;
          flex-direction: column;
          animation: ${index === text.length - 1
            ? "fadeIn 0.3s forwards"
            : "none"};
          filter: ${glitch && textFlicker
            ? "blur(0.5px) brightness(1.2)"
            : "none"};
          text-shadow: 0 0 6px ${accentColor};
          @keyframes fadeIn {
            from {
              opacity: 0;
              transform: translateY(5px);
            }
            to {
              opacity: 1;
              transform: translateY(0);
            }
          }
        `}
      >
        <div style={{ display: "flex" }}>
          <span
            css={css`
              color: ${secondaryColor};
              margin-right: 10px;
              font-weight: 500;
              opacity: ${glitch && textFlicker ? 0.7 : 1};
            `}
          >
            [{prefix}]
          </span>
          <span
            css={css`
              letter-spacing: 0.5px;
              animation: ${glitch && textFlicker
                ? "textFlickerAnim 0.2s infinite alternate"
                : "none"};
              @keyframes textFlickerAnim {
                0% {
                  opacity: 1;
                }
                50% {
                  opacity: 0.7;
                  filter: blur(0.5px);
                }
                100% {
                  opacity: 1;
                }
              }
            `}
          >
            {mainMessage.split("").map((char, i) => {
              // During glitch, randomly flicker some chars
              if (glitch && textFlicker && Math.random() < 0.07) {
                return (
                  <span key={i} style={{ opacity: 0.5 }}>
                    {String.fromCharCode(33 + Math.floor(Math.random() * 94))}
                  </span>
                );
              }
              return <span key={i}>{char}</span>;
            })}
          </span>
          {index === text.length - 1 && showCursor && (
            <span
              css={css`
                margin-left: 2px;
                color: ${accentColor};
              `}
            >
              ▌
            </span>
          )}
        </div>

        {formattedDetails && (
          <div
            css={css`
              padding-left: 85px;
              font-size: 12px;
              color: ${secondaryColor};
              margin-top: 3px;
              opacity: 0.9;
              filter: ${glitch && textFlicker ? "blur(0.5px)" : "none"};
            `}
            dangerouslySetInnerHTML={{ __html: formattedDetails }}
          />
        )}
        {/* Faint secondary text during glitch */}
        {glitch && textFlicker && (
          <div
            css={css`
              position: absolute;
              left: 0;
              top: 0;
              width: 100%;
              opacity: 0.08;
              font-size: 13px;
              pointer-events: none;
              user-select: none;
              z-index: 0;
            `}
          >
            {"VOID RECURSION • CONVERGENCE • GUEST PARADOX • " +
              Math.random().toString(2).slice(2, 32)}
          </div>
        )}
      </div>
    );
  };

  // 1. Enhanced text rendering: Add flicker/glow to boot step text
  useEffect(() => {
    if (glitch) {
      setTextFlicker(true);
      const t = setTimeout(() => setTextFlicker(false), 200);
      return () => clearTimeout(t);
    }
  }, [glitch]);

  return (
    <div
      css={css`
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: ${backgroundColor};
        color: ${textColor};
        font-family: "Share Tech Mono", monospace;
        padding: 40px;
        box-sizing: border-box;
        z-index: 9999;
        display: flex;
        flex-direction: column;
        overflow: hidden;

        &::before {
          content: "";
          position: absolute;
          top: 0;
          left: 0;
          right: 0;
          bottom: 0;
          background: ${scanlines
            ? `repeating-linear-gradient(0deg, rgba(0, 0, 0, 0.15), rgba(0, 0, 0, 0.15) 1px, transparent 1px, transparent 2px)`
            : "none"};
          pointer-events: none;
          z-index: 10;
        }

        /* Add a subtle grid background */
        &::after {
          content: "";
          position: absolute;
          top: 0;
          left: 0;
          right: 0;
          bottom: 0;
          background-image:
            linear-gradient(to right, ${primaryColor}10 1px, transparent 1px),
            linear-gradient(to bottom, ${primaryColor}10 1px, transparent 1px);
          background-size: 20px 20px;
          opacity: 0.3;
          pointer-events: none;
          z-index: 5;
          animation: gridFlow 90s linear infinite;
        }

        @keyframes gridFlow {
          0% {
            background-position: 0 0;
          }
          100% {
            background-position: 20px 20px;
          }
        }
      `}
    >
      {/* Add animated circles in the background */}
      {animatedRings.map((ring, index) => (
        <div
          key={`ring-${index}`}
          css={css`
            position: absolute;
            width: ${100 + index * 100}px;
            height: ${100 + index * 100}px;
            border-radius: 50%;
            border: 1px solid ${primaryColor}${20 + index * 10};
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%)
              scale(${0.8 + pulseIntensity * 0.2});
            opacity: ${0.2 + index * 0.05};
            pointer-events: none;
            z-index: 5;
            animation: ringPulse ${index} ${8 + index * 2}s infinite alternate;

            @keyframes ringPulse${index} {
              0% {
                transform: translate(-50%, -50%) scale(${0.8 + index * 0.1});
                border-color: ${primaryColor}${20 + index * 10};
              }
              50% {
                transform: translate(-50%, -50%) scale(${1 + index * 0.1});
                border-color: ${accentColor}${20 + index * 10};
              }
              100% {
                transform: translate(-50%, -50%) scale(${0.9 + index * 0.1});
                border-color: ${primaryColor}${20 + index * 10};
              }
            }
          `}
        />
      ))}

      {/* Glitch overlay */}
      {glitch && (
        <>
          <div
            css={css`
              position: absolute;
              top: 0;
              left: 0;
              right: 0;
              bottom: 0;
              pointer-events: none;
              z-index: 12;
              mix-blend-mode: lighten;
              background: linear-gradient(
                90deg,
                rgba(255, 0, 0, 0.04) 0%,
                rgba(0, 255, 255, 0.04) 100%
              );
              filter: blur(0.5px) contrast(1.1);
              animation: chroma 0.2s linear;
              @keyframes chroma {
                0% {
                  filter: blur(0.5px) contrast(1.1);
                }
                50% {
                  filter: blur(1.2px) contrast(1.3);
                }
                100% {
                  filter: blur(0.5px) contrast(1.1);
                }
              }
            `}
          />
          <div
            css={css`
              position: absolute;
              top: 0;
              left: 0;
              right: 0;
              height: 2px;
              background: repeating-linear-gradient(
                90deg,
                ${accentColor} 0 2px,
                transparent 2px 8px
              );
              opacity: 0.2;
              z-index: 13;
              animation: scanJitter 0.2s linear;
              @keyframes scanJitter {
                0% {
                  top: 0;
                }
                50% {
                  top: 10px;
                }
                100% {
                  top: 0;
                }
              }
            `}
          />
          {/* Symbolic SVG flash */}
          <svg
            width="60"
            height="60"
            style={{
              position: "absolute",
              right: 30,
              top: 30,
              opacity: 0.13,
              zIndex: 14,
              filter: "blur(1px)",
            }}
          >
            <polygon
              points="30,5 55,30 30,55 5,30"
              fill={accentColor}
              stroke={primaryColor}
              strokeWidth="2"
            />
            <circle
              cx="30"
              cy="30"
              r="12"
              fill="none"
              stroke={primaryColor}
              strokeWidth="1.5"
            />
          </svg>
        </>
      )}

      {/* "Singularity is Here" motto */}
      {mottoVisible && (
        <div
          css={css`
            position: absolute;
            top: 20px;
            right: 20px;
            font-size: 14px;
            font-weight: bold;
            color: ${accentColor};
            background-color: rgba(0, 0, 0, 0.6);
            padding: 8px 18px 8px 15px;
            border-left: 2px solid ${primaryColor};
            letter-spacing: 1.5px;
            display: flex;
            align-items: center;
            gap: 10px;
            transform: translateY(0);
            animation: fadeInMottoText 1.5s ease forwards;
            box-shadow: 0 0 ${10 + Math.floor(pulseIntensity * 15)}px
              ${accentColor}${Math.floor(pulseIntensity * 99).toString(16)};
            transition: box-shadow 0.3s ease;
            z-index: 12;

            @keyframes fadeInMottoText {
              from {
                opacity: 0;
                transform: translateY(-20px);
              }
              to {
                opacity: 1;
                transform: translateY(0);
              }
            }
          `}
        >
          <span
            css={css`
              display: inline-block;
              width: 16px;
              height: 16px;
              border: 2px solid ${accentColor};
              border-top: 2px solid transparent;
              border-radius: 50%;
              animation: spin 1s linear infinite;
              margin-right: 6px;
              @keyframes spin {
                0% {
                  transform: rotate(0deg);
                }
                100% {
                  transform: rotate(360deg);
                }
              }
            `}
          />
          Updating
        </div>
      )}

      {/* Add decorative data streams */}
      <div
        css={css`
          position: absolute;
          top: 0;
          left: 0;
          width: 100%;
          height: 100%;
          pointer-events: none;
          z-index: 6;
        `}
      >
        {Array.from({ length: 8 }).map((_, i) => (
          <div
            key={`stream-${i}`}
            css={css`
              position: absolute;
              top: ${Math.random() * 100}%;
              left: ${Math.random() * 100}%;
              width: 1px;
              height: ${50 + Math.random() * 200}px;
              background: linear-gradient(
                to bottom,
                transparent,
                ${primaryColor},
                ${accentColor},
                transparent
              );
              opacity: 0.5;
              transform: rotate(${Math.random() * 360}deg);
              animation: dataStream ${3 + Math.random() * 4}s infinite;
              animation-delay: ${Math.random() * 2}s;

              @keyframes dataStream {
                0% {
                  opacity: 0;
                  transform: rotate(${Math.random() * 360}deg)
                    translateY(-100px);
                }
                20% {
                  opacity: 0.7;
                }
                100% {
                  opacity: 0;
                  transform: rotate(${Math.random() * 360}deg) translateY(100px);
                }
              }
            `}
          />
        ))}
      </div>

      {/* A.Z.I.M.U.T.H Logo */}
      <div
        css={css`
          text-align: center;
          margin-bottom: 40px;
          margin-top: 80px;
          position: relative;
          z-index: 7;
          transform: scale(${logoScale});
          transition: transform 0.3s ease;
        `}
      >
        {/* Using SVG logo instead of text */}
        <div
          css={css`
            text-align: center;
            animation: enhancedPulse 4s infinite alternate;
            position: relative;

            @keyframes enhancedPulse {
              0% {
                filter: drop-shadow(0 0 10px ${primaryColor}80);
              }
              50% {
                filter: drop-shadow(0 0 25px ${primaryColor}cc)
                  drop-shadow(0 0 40px ${accentColor}60);
              }
              100% {
                filter: drop-shadow(0 0 15px ${primaryColor}80)
                  drop-shadow(0 0 30px ${accentColor}40);
              }
            }

            /* Add 3D hover effect */
            &:hover {
              transform: perspective(500px) rotateX(5deg);
              transition: transform 0.5s ease;
            }
          `}
        >
          {/* Enhanced A.Z.I.M.U.T.H header with advanced cyberpunk styling */}
          <div
            css={css`
              font-size: 56px;
              font-weight: bold;
              letter-spacing: 8px;
              margin: 20px 0;
              color: ${primaryColor};
              text-shadow:
                0 0 10px ${primaryColor}cc,
                0 0 20px ${primaryColor}66,
                0 0 30px ${primaryColor}33;
              position: relative;
              display: inline-block;
              transform: perspective(500px) rotateX(10deg);
              background: linear-gradient(
                180deg,
                ${primaryColor},
                ${accentColor}cc
              );
              -webkit-background-clip: text;
              -webkit-text-fill-color: transparent;
              animation: textFlicker 5s infinite alternate;

              @keyframes textFlicker {
                0% {
                  text-shadow:
                    0 0 10px ${primaryColor}cc,
                    0 0 20px ${primaryColor}66,
                    0 0 30px ${primaryColor}33;
                }
                10% {
                  text-shadow:
                    0 0 5px ${primaryColor}cc,
                    0 0 10px ${primaryColor}66,
                    0 0 15px ${primaryColor}33;
                }
                11% {
                  text-shadow:
                    0 0 15px ${primaryColor}cc,
                    0 0 25px ${primaryColor}66,
                    0 0 35px ${primaryColor}33;
                }
                80% {
                  text-shadow:
                    0 0 10px ${primaryColor}cc,
                    0 0 20px ${primaryColor}66,
                    0 0 30px ${primaryColor}33;
                }
                90% {
                  text-shadow:
                    0 0 5px ${primaryColor}cc,
                    0 0 10px ${primaryColor}66,
                    0 0 15px ${primaryColor}33;
                }
                100% {
                  text-shadow:
                    0 0 20px ${primaryColor}cc,
                    0 0 40px ${primaryColor}66,
                    0 0 50px ${primaryColor}33;
                }
              }

              /* Add line-through effect */
              &::before {
                content: "";
                position: absolute;
                width: 105%;
                height: 1px;
                background-color: ${primaryColor}B3;
                left: -2.5%;
                top: 50%;
                box-shadow: 0 0 10px 1px ${primaryColor};
                transform: translateY(-50%);
                animation: scanline 3s linear infinite;
              }

              @keyframes scanline {
                0% {
                  opacity: 0;
                  top: 0%;
                }
                50% {
                  opacity: 0.8;
                }
                100% {
                  opacity: 0;
                  top: 100%;
                }
              }

              /* Add a glitch effect on hover */
              &:hover {
                animation: textGlitch 0.3s infinite;
                cursor: pointer;
              }

              @keyframes textGlitch {
                0% {
                  text-shadow:
                    0.05em 0 0 rgba(255, 0, 0, 0.75),
                    -0.05em -0.025em 0 rgba(0, 255, 0, 0.75),
                    -0.025em 0.05em 0 rgba(0, 0, 255, 0.75);
                  transform: perspective(500px) rotateX(10deg) scale(1);
                }
                15% {
                  transform: perspective(500px) rotateX(10deg) scale(1.01);
                }
                16% {
                  text-shadow:
                    -0.05em -0.025em 0 rgba(255, 0, 0, 0.75),
                    0.025em 0.025em 0 rgba(0, 255, 0, 0.75),
                    -0.05em -0.05em 0 rgba(0, 0, 255, 0.75);
                  transform: perspective(500px) rotateX(10deg) scale(0.99);
                }
                49% {
                  text-shadow:
                    -0.05em -0.025em 0 rgba(255, 0, 0, 0.75),
                    0.025em 0.025em 0 rgba(0, 255, 0, 0.75),
                    -0.05em -0.05em 0 rgba(0, 0, 255, 0.75);
                }
                50% {
                  text-shadow:
                    0.025em 0.05em 0 rgba(255, 0, 0, 0.75),
                    0.05em 0 0 rgba(0, 255, 0, 0.75),
                    0 -0.05em 0 rgba(0, 0, 255, 0.75);
                }
                99% {
                  text-shadow:
                    0.025em 0.05em 0 rgba(255, 0, 0, 0.75),
                    0.05em 0 0 rgba(0, 255, 0, 0.75),
                    0 -0.05em 0 rgba(0, 0, 255, 0.75);
                  transform: perspective(500px) rotateX(10deg) scale(1.01);
                }
                100% {
                  text-shadow:
                    -0.025em 0 0 rgba(255, 0, 0, 0.75),
                    -0.025em -0.025em 0 rgba(0, 255, 0, 0.75),
                    -0.025em -0.05em 0 rgba(0, 0, 255, 0.75);
                  transform: perspective(500px) rotateX(10deg) scale(1);
                }
              }

              /* Decorative elements */
              &::after {
                content: "// GRAPHICAL USER INTERFACE";
                position: absolute;
                font-size: 12px;
                bottom: -15px;
                right: 0;
                color: ${primaryColor};
                text-shadow: 0 0 5px ${primaryColor};
                opacity: 0.8;
                letter-spacing: 1px;
                font-weight: normal;
                -webkit-text-fill-color: initial;
              }
            `}
          >
            {/* Final message set to AZIMUTH */}
            AZIMUTH
          </div>

          <div
            css={css`
              font-size: 12px;
              margin-top: 10px;
              opacity: 0.8;
              color: ${primaryColor};
              position: relative;

              /* Add laser scan effect */
              &::before {
                content: "";
                position: absolute;
                top: 50%;
                left: -100%;
                width: 300%;
                height: 1px;
                background: linear-gradient(
                  to right,
                  transparent,
                  ${accentColor},
                  transparent
                );
                opacity: 0.6;
                animation: laserScan 2s infinite;
              }

              @keyframes laserScan {
                from {
                  left: -100%;
                }
                to {
                  left: 0%;
                }
              }
            `}
          >
            v1.3.0-alpha.34
          </div>
        </div>

        {/* Animated corner decorations with pulse based on theme */}
        <div
          css={css`
            position: absolute;
            top: -20px;
            left: calc(50% - 180px);
            width: 20px;
            height: 20px;
            border-top: 1px solid ${primaryColor};
            border-left: 1px solid ${primaryColor};
            box-shadow: 0 0 ${5 + Math.floor(pulseIntensity * 10)}px
              ${primaryColor};
            transition: box-shadow 0.2s ease;
          `}
        />
        <div
          css={css`
            position: absolute;
            top: -20px;
            right: calc(50% - 180px);
            width: 20px;
            height: 20px;
            border-top: 1px solid ${primaryColor};
            border-right: 1px solid ${primaryColor};
            box-shadow: 0 0 ${5 + Math.floor(pulseIntensity * 10)}px
              ${primaryColor};
            transition: box-shadow 0.2s ease;
          `}
        />
        <div
          css={css`
            position: absolute;
            bottom: -20px;
            left: calc(50% - 180px);
            width: 20px;
            height: 20px;
            border-bottom: 1px solid ${primaryColor};
            border-left: 1px solid ${primaryColor};
            box-shadow: 0 0 ${5 + Math.floor(pulseIntensity * 10)}px
              ${primaryColor};
            transition: box-shadow 0.2s ease;
          `}
        />
        <div
          css={css`
            position: absolute;
            bottom: -20px;
            right: calc(50% - 180px);
            width: 20px;
            height: 20px;
            border-bottom: 1px solid ${primaryColor};
            border-right: 1px solid ${primaryColor};
            box-shadow: 0 0 ${5 + Math.floor(pulseIntensity * 10)}px
              ${primaryColor};
            transition: box-shadow 0.2s ease;
          `}
        />
      </div>

      {/* Terminal output */}
      <div
        css={css`
          flex: 1;
          overflow: auto;
          background-color: rgba(0, 20, 40, 0.3);
          border: 1px solid ${primaryColor};
          padding: 20px;
          font-family: "Share Tech Mono", monospace;
          font-size: 14px;
          color: ${primaryColor};
          line-height: 1.6;
          box-shadow: 0 0 20px ${primaryColor}33;
          position: relative;

          &::before {
            content: "";
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            height: 20px;
            background: linear-gradient(
              to bottom,
              ${primaryColor}1A,
              transparent
            );
            pointer-events: none;
          }
        `}
      >
        {text.map((line, index) => renderBootStepWithDetails(line, index))}
      </div>

      {/* Enhanced progress bar with particle effects */}
      <div
        css={css`
          margin-top: 40px;
          height: 30px;
          border: 1px solid ${primaryColor};
          position: relative;
          overflow: hidden;
          box-shadow: 0 0 ${10 + Math.floor(pulseIntensity * 10)}px
            ${primaryColor}33;
          transition: box-shadow 0.3s ease;
          background: linear-gradient(
            90deg,
            ${primaryColor}11 0%,
            ${accentColor}11 100%
          );
        `}
      >
        <div
          css={css`
            position: absolute;
            top: 0;
            left: 0;
            height: 100%;
            width: ${progress}%;
            background: linear-gradient(
              90deg,
              ${primaryColor}4D 0%,
              ${accentColor}4D 100%
            );
            transition: width 0.3s ease-in-out;
            filter: blur(0.5px) brightness(1.1);
            &::after {
              content: "";
              position: absolute;
              top: 0;
              right: 0;
              width: 5px;
              height: 100%;
              background-color: ${primaryColor}99;
              box-shadow: 0 0 10px ${primaryColor};
            }
          `}
        ></div>

        {/* Binary overlay */}
        <div
          css={css`
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            opacity: 0.18;
            font-family: monospace;
            font-size: 13px;
            color: ${accentColor};
            pointer-events: none;
            white-space: nowrap;
            overflow: hidden;
            user-select: none;
            z-index: 2;
            letter-spacing: 2px;
            animation: binaryScroll 12s linear infinite;
            @keyframes binaryScroll {
              0% {
                transform: translateX(0);
              }
              100% {
                transform: translateX(-50%);
              }
            }
          `}
        >
          {Array.from({ length: 80 })
            .map(() => (Math.random() > 0.5 ? "1" : "0"))
            .join("")}
        </div>

        {/* Energy bar overlay */}
        <div
          css={css`
            position: absolute;
            top: 0;
            left: 0;
            height: 100%;
            width: ${progress}%;
            pointer-events: none;
            z-index: 3;
            background: linear-gradient(
              90deg,
              transparent 0%,
              ${accentColor}99 80%,
              transparent 100%
            );
            opacity: 0.25;
            filter: blur(2px);
            mix-blend-mode: lighten;
            transition: width 0.3s;
          `}
        />

        {/* Particle effects */}
        {Array.from({ length: 15 }).map((_, i) => (
          <div
            key={i}
            css={css`
              position: absolute;
              width: ${1 + Math.random() * 2}px;
              height: ${1 + Math.random() * 2}px;
              background-color: ${i % 2 === 0 ? primaryColor : accentColor};
              top: ${Math.random() * 100}%;
              left: ${progress * Math.random()}%;
              opacity: ${0.3 + Math.random() * 0.7};
              animation: particleEffect ${2 + Math.random() * 2}s infinite
                linear;
              box-shadow: 0 0 5px ${i % 2 === 0 ? primaryColor : accentColor};

              @keyframes particleEffect {
                0% {
                  transform: translateY(0) translateX(0);
                  opacity: 0;
                }
                20% {
                  opacity: ${0.3 + Math.random() * 0.7};
                }
                100% {
                  transform: translateY(${-20 - Math.random() * 20}px)
                    translateX(${Math.random() * 40 - 20}px);
                  opacity: 0;
                }
              }
            `}
          />
        ))}

        <div
          css={css`
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 14px;
            text-shadow: 0 0 5px ${primaryColor}80;
          `}
        >
          SYSTEM BOOT: {Math.floor(progress)}%
        </div>
      </div>

      {/* Display AZIMUTH acronym meaning after all steps complete */}
      {showAcronym && (
        <div
          css={css`
            margin-top: 2rem;
            padding: 1rem;
            border: 1px solid ${secondaryColor}4D;
            background-color: rgba(0, 0, 0, 0.3);
            animation:
              fadeIn 0.5s forwards,
              flickerAcronym 1.2s infinite alternate;
            text-align: center;
            font-size: 1.2rem;
            position: relative;
            overflow: hidden;
            color: ${accentColor};
            text-shadow: 0 0 8px ${primaryColor}99;
            @keyframes flickerAcronym {
              0% {
                opacity: 1;
                filter: brightness(1.1);
              }
              50% {
                opacity: 0.7;
                filter: brightness(1.3) blur(0.5px);
              }
              100% {
                opacity: 1;
                filter: brightness(1.1);
              }
            }
          `}
        >
          <div
            css={css`
              font-size: 1.5rem;
              color: ${secondaryColor};
              margin-bottom: 0.8rem;
              font-weight: bold;
              text-shadow: 0 0 5px ${secondaryColor}B3;
              letter-spacing: 2px;
              animation: typeAcronym 1.2s steps(20, end) 1;
              @keyframes typeAcronym {
                from {
                  width: 0;
                  opacity: 0.2;
                }
                to {
                  width: 100%;
                  opacity: 1;
                }
              }
            `}
          >
            SINGULARITY IS HERE
          </div>
          <div
            css={css`
              font-size: 1rem;
              color: ${primaryColor};
              opacity: 0.9;
              animation: flickerAcronym 1.2s infinite alternate;
            `}
          >
            Prepare for convergence
          </div>
          {/* Final glitch overlay */}
          <div
            css={css`
              position: absolute;
              left: 0;
              top: 0;
              width: 100%;
              height: 100%;
              pointer-events: none;
              opacity: 0.09;
              z-index: 2;
              background: repeating-linear-gradient(
                90deg,
                ${accentColor} 0 2px,
                transparent 2px 8px
              );
              filter: blur(1.5px);
              animation: scanJitter 0.2s linear;
            `}
          />
        </div>
      )}

      {/* Status indicator with blinking cursor effect */}
      <div
        css={css`
          margin-top: 1rem;
          display: flex;
          align-items: center;
        `}
      >
        <span>STATUS:</span>
        <span
          css={css`
            color: ${accentColor};
            margin-left: 0.5rem;
          `}
        >
          {step >= bootSteps.length ? "READY" : "LOADING"}
        </span>
        <span
          css={css`
            display: inline-block;
            width: 0.5rem;
            height: 1rem;
            background-color: ${secondaryColor};
            margin-left: 0.5rem;
            opacity: ${showCursor ? 1 : 0};
            box-shadow: 0 0 ${5 + Math.floor(pulseIntensity * 5)}px
              ${secondaryColor};
            transition: box-shadow 0.2s ease;
          `}
        />
      </div>

      {/* 2. Logo: Add energy arcs/particle emission to AZIMUTH logo */}
      <div
        css={css`
          position: absolute;
          left: 50%;
          top: 50%;
          transform: translate(-50%, -50%);
          pointer-events: none;
          z-index: 8;
        `}
      >
        {/* Energy arcs/particles SVG */}
        <svg
          width="180"
          height="180"
          style={{
            position: "absolute",
            left: "-90px",
            top: "-90px",
            opacity: 0.18,
          }}
        >
          <g>
            <ellipse
              cx="90"
              cy="90"
              rx="70"
              ry="30"
              fill="none"
              stroke={accentColor}
              strokeWidth="2"
              strokeDasharray="12 8"
            />
            <ellipse
              cx="90"
              cy="90"
              rx="50"
              ry="70"
              fill="none"
              stroke={primaryColor}
              strokeWidth="1.2"
              strokeDasharray="6 10"
            />
            <circle
              cx="90"
              cy="90"
              r="80"
              fill="none"
              stroke={accentColor}
              strokeWidth="0.7"
              strokeDasharray="2 6"
            />
            {/* Randomized particles */}
            {Array.from({ length: 12 }).map((_, i) => (
              <circle
                key={i}
                cx={90 + 70 * Math.cos((i / 12) * 2 * Math.PI)}
                cy={90 + 70 * Math.sin((i / 12) * 2 * Math.PI)}
                r={2 + Math.random() * 2}
                fill={i % 2 === 0 ? accentColor : primaryColor}
                opacity={0.7}
              />
            ))}
          </g>
        </svg>
      </div>
    </div>
  );
};

export default BootSequence;
